import React from 'react';
import { Link, graphql, useStaticQuery } from 'gatsby';
import Img from 'gatsby-image';
import styled from 'styled-components';
import { Icon } from '@deer-ui/core/icon';
import { Label } from '@deer-ui/core/label';
import { DocSearch } from './doc-search';
import { useColorMode } from './theme';
import { MainContentWrapper } from './common-style';
const QUERY = graphql `
  query Header {
    logo: file(relativePath: { eq: "logo.png" }) {
      childImageSharp {
        fixed(width: 34, height: 34) {
          ...GatsbyImageSharpFixed_noBase64
        }
      }
    }

    site {
      siteMetadata {
        title
        github
        algoliaDocSearch {
          enabled
          apiKey
          indexName
        }
        nav {
          title
          url
        }
      }
    }
  }
`;
const Container = styled.div `
  background-color: ${({ theme }) => theme.color.body};
  border-bottom: 1px solid #f7f7f7;
  padding: 16 0;
`;
const Header = styled.div `
  display: flex;
  flex-flow: row nowrap;
  position: relative;
  padding: 0 20px;
`;
const LogoText = styled.span `
  margin-left: 10px;
  color: #444;
  font-size: 18px;
`;
const LogoLink = styled(Link) `
  margin-right: 10px;
`;
const Box = styled.span `

`;
const Nav = styled.nav `
  /* height: 34; */
  margin-left: 10;
  position: relative;
  display: flex;
`;
const NavList = styled.ul `
  list-style: none;
  margin: 0;
  padding: 0;
  align-self: flex-end;
  display: flex;
  overflow-x: auto;
  list-style: none;
  margin: 0rem;
`;
const SideHelpers = styled(NavList) `
`;
const HelperItem = styled.li `
  font-size: 18px;
  color: #666;

  a {
    color: inherit;
  }
`;
const NavListItem = styled.li `
  color: #000;
  display: inline-block;
  line-height: 2.8rem;
  color: #666;
`;
const modeIcons = {
    light: 'sun',
    dark: 'moon',
};
function getInverseMode(mode) {
    return mode === 'light' ? 'dark' : 'light';
}
function ColorModeSwitcher() {
    const [mode, setMode] = useColorMode();
    return (React.createElement(Label, { onClick: () => { setMode(getInverseMode); } },
        React.createElement(Icon, { n: modeIcons[mode] })));
}
export function ProjectHeader() {
    const data = useStaticQuery(QUERY);
    return (React.createElement(Container, null,
        React.createElement(MainContentWrapper, null,
            React.createElement(Header, { className: "layout a-i-c flex" },
                React.createElement(LogoLink, { to: "/", className: "layout a-i-c" },
                    React.createElement(Img, { fixed: data.logo.childImageSharp.fixed, alt: data.site.siteMetadata.title }),
                    React.createElement(LogoText, null, data.site.siteMetadata.title)),
                React.createElement(Nav, null,
                    React.createElement(NavList, { className: "layout a-i-c" }, data.site.siteMetadata.nav.map(({ title, url }) => (React.createElement(NavListItem, { key: title },
                        React.createElement(Link, { to: url }, title)))))),
                React.createElement("span", { className: "flex" }),
                React.createElement(Box, null, data.site.siteMetadata.algoliaDocSearch.enabled && (React.createElement(DocSearch, Object.assign({}, data.site.siteMetadata.algoliaDocSearch)))),
                React.createElement(Nav, null,
                    React.createElement(SideHelpers, { className: "layout a-i-c" },
                        React.createElement(HelperItem, null,
                            React.createElement(Label, null,
                                React.createElement("a", { href: data.site.siteMetadata.github, target: "_blank", rel: "noopener noreferrer" },
                                    React.createElement(Icon, { n: "github", s: "b" }))))))))));
}
