import React from 'react';
import styled from 'styled-components';
import { ToolTip } from '@deer-ui/core';
const Table = styled.table `
  display: table !important;
  background-color: transparent;
  border-collapse: collapse;
  color: text;
  overflow-y: hidden;
  overflow-x: initial;
  width: 100%;
  font-size: 14;
  padding: 0;
  border-spacing: 0;
  border-style: hidden;
  table-layout: auto;
  border-radius: 4;
`;
const Thead = styled.thead `
  color: text;
  background-color: secondary-bg;
  text-align: left;
`;
const Th = styled.th `
  font-weight: 400;
  padding: 20;
  &:first-child {
    border-radius: 4 0 0;
  }
  &:last-child {
    border-radius: 0 4 0;
  }
`;
const Tbody = styled.tbody `
  > tr {
    border-top: 1;
    border-color: border;
  }
`;
const Td = styled.td `
  line-height: 2;
  font-weight: 200;
  padding: 12 20;
`;
const GROUP_REGEXP = /^\[(.*)]\s+/;
function sanitizeDescription(description) {
    return description && description.replace(GROUP_REGEXP, '');
}
function getGroup(meta) {
    if (!meta.description)
        return null;
    const matches = meta.description.match(GROUP_REGEXP);
    if (!matches)
        return null;
    return matches[1];
}
export function Props({ of }) {
    console.dir(of);
    return React.createElement("span", null);
    const properties = React.useMemo(() => Object.entries(of.propTypes).reduce((properties, [name, prop]) => {
        const group = getGroup(prop.__meta) || 'default';
        properties[group] = properties[group] || [];
        properties[group].push([name, prop]);
        return properties;
    }, {}), []);
    const [groupsState, setGroupsState] = React.useState(() => Object.keys(properties).reduce((state, group) => {
        if (group === 'default')
            return state;
        properties[group] = properties[group] || [];
        properties[group].push();
        return Object.assign(Object.assign({}, state), { [group]: false });
    }, []));
    return (React.createElement(Table, null,
        React.createElement(Thead, null,
            React.createElement("tr", null,
                React.createElement(Th, null, "Property"),
                React.createElement(Th, null, "Type"),
                React.createElement(Th, null, "Required"),
                React.createElement(Th, null, "Default"),
                React.createElement(Th, null, "Description"))),
        React.createElement(Tbody, null, Object.entries(properties).map(([group, propTypes]) => {
            return (React.createElement(React.Fragment, { key: group },
                group !== 'default' && (React.createElement("tr", null,
                    React.createElement(Td, { colSpan: 5, style: { textAlign: 'center' } },
                        React.createElement("a", { href: "#", onClick: (event) => {
                                event.preventDefault();
                                setGroupsState((state) => (Object.assign(Object.assign({}, state), { [group]: !state[group] })));
                            } },
                            groupsState[group] ? 'Hide' : 'Show',
                            " ",
                            group,
                            " properties")))),
                propTypes.map(([name, prop]) => {
                    const meta = prop.__meta;
                    const propType = meta.toString();
                    const tooltip = propType !== meta.type.name;
                    const group = getGroup(meta);
                    if (group && group !== 'default' && !groupsState[group]) {
                        return null;
                    }
                    return (React.createElement("tr", { key: name },
                        React.createElement(Td, null, name),
                        React.createElement(Td, null, tooltip ? (React.createElement("a", { href: "#" },
                            tooltip && (React.createElement(ToolTip, { title: propType })),
                            meta.type.name)) : (propType)),
                        React.createElement(Td, null, meta.required ? 'true' : 'false'),
                        React.createElement(Td, null, meta.defaultValue ? meta.defaultValue.value : '-'),
                        React.createElement(Td, { dangerouslySetInnerHTML: {
                                __html: sanitizeDescription(meta.description),
                            } })));
                })));
        }))));
}
